@@ -30,7 +30,7 @@ class Node:
             print('closing...')
             quit()
         else:
-            node.nw.send('re', 'set', 'scriptlet', '["' + cmd.strip() + '"]')
+            node.nw.send('re', 'set', 'scriptlet', '"' + cmd.strip() + '"')
 
 
 if __name__ == '__main__':
